==> artan-react-ui-sample-0.0.2.tgz: package/src/Presentation/components/UI/Dialogs/MembersList/MembersList.tsx <==
import React, { useEffect, useState } from 'react';
import './MembersList.scss';
import ColumnContainer from '../../../containers/ColumnContainer/ColumnContainer';
import ActiveSvg from '../../svgs/ActiveSvg/ActiveSvg';
import Close from '../../svgs/Icons/Navigation/Close';
import { FunctionTypeVoidToVoid } from '../../../../Views/Base/BaseViewModel';
import { UserEntity } from '../../../../../Domain/entity/UserEntity';
import Search from '../../svgs/Icons/Navigation/Search';
import UsersList from '../DialogInformation/UsersList/UsersList';

type MembersListProps = {
  closeInformationHandler: FunctionTypeVoidToVoid;
  members: UserEntity[];
};
// eslint-disable-next-line react/function-component-definition
const MembersList: React.FC<MembersListProps> = ({
  closeInformationHandler,
  members,
}: MembersListProps) => {
  const [userNameForFilter, setUserNameForFilter] = useState<string>('');
  const [membersListFilter, setMembersListFilter] = useState<UserEntity[]>([
    ...members,
  ]);

  useEffect(() => {
    if (userNameForFilter.length > 0) {
      const newFilteredMembers = members.filter((item) =>
        item.full_name ? item.full_name.includes(userNameForFilter, 0) : false,
      );

      setMembersListFilter([...newFilteredMembers]);
    } else {
      setMembersListFilter([...members]);
    }
  }, [userNameForFilter]);

  return (
    <div className="members-container">
      <ColumnContainer>
        <div className="members-container--members-information-wrapper">
          <div className="members-container--members-information-wrapper__members-information">
            Members
          </div>
          <div className="members-container--members-information-wrapper__members-information-count">
            {members.length}
          </div>
          <div className="members-container--members-information-wrapper__members-close">
            <ActiveSvg
              content={<Close applyZoom color="var(--secondary-elements)" />}
              clickAction={() => {
                if (closeInformationHandler) {
                  closeInformationHandler();
                }
              }}
            />
          </div>
        </div>
        <div className="members-container--members-search-wrapper">
          <div className="members-container--members-search-wrapper__search-member-input">
            <Search
              applyZoom
              width="24"
              height="24"
              color="var(--tertiary-elements)"
            />
            <input
              type="text"
              style={{ width: '280px' }}
              value={userNameForFilter}
              onChange={(event) => {
                setUserNameForFilter(event.target.value);
              }}
              placeholder="Search"
            />
          </div>
        </div>
        <div className="members-container--members-list-wrapper">
          <UsersList
            usersFirstPageToView={[...membersListFilter]}
            allUsers={[...membersListFilter]}
            usersInDialogCount={membersListFilter.length}
          />
        </div>
      </ColumnContainer>
    </div>
  );
};

export default MembersList;

==> artan-react-ui-sample-0.0.20.tgz: package/src/Presentation/components/UI/Dialogs/MembersList/MembersList.tsx <==
import React, { useEffect, useState } from 'react';
import './MembersList.scss';
import ColumnContainer from '../../../containers/ColumnContainer/ColumnContainer';
import ActiveSvg from '../../svgs/ActiveSvg/ActiveSvg';
import Close from '../../svgs/Icons/Navigation/Close';
import { FunctionTypeVoidToVoid } from '../../../../Views/Base/BaseViewModel';
import { UserEntity } from '../../../../../Domain/entity/UserEntity';
import Search from '../../svgs/Icons/Navigation/Search';
import UsersList from '../DialogInformation/UsersList/UsersList';

type MembersListProps = {
  closeInformationHandler: FunctionTypeVoidToVoid;
  members: UserEntity[];
};
// eslint-disable-next-line react/function-component-definition
const MembersList: React.FC<MembersListProps> = ({
  closeInformationHandler,
  members,
}: MembersListProps) => {
  const [userNameForFilter, setUserNameForFilter] = useState<string>('');
  const [membersListFilter, setMembersListFilter] = useState<UserEntity[]>([
    ...members,
  ]);

  useEffect(() => {
    if (userNameForFilter.length >= 3) {
      const newFilteredMembers = members.filter((item) =>
        item.full_name
          ? item.full_name
              .toUpperCase()
              .includes(userNameForFilter.toUpperCase(), 0)
          : false,
      );

      setMembersListFilter([...newFilteredMembers]);
    } else {
      setMembersListFilter([...members]);
    }
  }, [userNameForFilter]);

  return (
    <div className="members-container">
      <ColumnContainer>
        <div className="members-container--members-information-wrapper">
          <div className="members-container--members-information-wrapper__members-information">
            Members
          </div>
          <div className="members-container--members-information-wrapper__members-information-count">
            {members.length}
          </div>
          <div className="members-container--members-information-wrapper__members-close">
            <ActiveSvg
              content={<Close applyZoom color="var(--secondary-elements)" />}
              clickAction={() => {
                if (closeInformationHandler) {
                  closeInformationHandler();
                }
              }}
            />
          </div>
        </div>
        <div className="members-container--members-search-wrapper">
          <div className="members-container--members-search-wrapper__search-member-input">
            <Search
              applyZoom
              width="24"
              height="24"
              color="var(--tertiary-elements)"
            />
            <input
              type="text"
              style={{ width: '280px' }}
              value={userNameForFilter}
              onChange={(event) => {
                setUserNameForFilter(event.target.value);
              }}
              placeholder="Search"
            />
          </div>
        </div>
        <div className="members-container--members-list-wrapper">
          <UsersList
            usersFirstPageToView={[...membersListFilter]}
            allUsers={[...membersListFilter]}
            usersInDialogCount={membersListFilter.length}
          />
        </div>
      </ColumnContainer>
    </div>
  );
};

export default MembersList;
